<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>Filtr:</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../forms/fontdialog.ui" line="14"/>
        <location filename="../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>Vyberte písmo pro terminál</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>Písmo:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>Velikost:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>Náhled</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>Bookmarks</source>
        <translation>Záložky</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="192"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>Terminál zobrazíte stisknutím „%1“.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="234"/>
        <source>&amp;Clear Active Terminal</source>
        <translation>&amp;Vyčistit právě zaměřený terminál</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="241"/>
        <source>&amp;Next Tab</source>
        <translation>&amp;Následující panel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="244"/>
        <source>&amp;Previous Tab</source>
        <translation>&amp;Předchozí panel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="247"/>
        <source>&amp;Previous Tab in History</source>
        <translation>V historii &amp;předchozí panel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="250"/>
        <source>&amp;Next Tab in History</source>
        <translation>V historii &amp;následující panel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="253"/>
        <source>Move Tab &amp;Left</source>
        <translation>Posunout panel do&amp;leva</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>Move Tab &amp;Right</source>
        <translation>Posunout panel dop&amp;rava</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>Tab</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>Go to</source>
        <translation>Přejít na</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="275"/>
        <source>Split Terminal &amp;Horizontally</source>
        <translation>&amp;Rozdělit terminál vodorovně</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Split Terminal &amp;Vertically</source>
        <translation>Rozdělit terminál s&amp;visle</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>&amp;Collapse Subterminal</source>
        <translation>&amp;Zrušit dílčí terminál</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>&amp;Top Subterminal</source>
        <translation>Na dílčí &amp;terminál výše</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="289"/>
        <source>&amp;Bottom Subterminal</source>
        <translation>Na &amp;dílčí terminál níže</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="292"/>
        <source>L&amp;eft Subterminal</source>
        <translation>Na dílčí t&amp;erminál vlevo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="295"/>
        <source>R&amp;ight Subterminal</source>
        <translation>Na dílčí term&amp;inál vpravo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>Copy &amp;Selection</source>
        <translation>&amp;Zkopírovat výběr</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="305"/>
        <source>Paste Clip&amp;board</source>
        <translation>Vložit o&amp;bsah schránky</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Paste S&amp;election</source>
        <translation>&amp;Vložit výběr</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source>Zoom &amp;in</source>
        <translation>Zvětš&amp;it</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="314"/>
        <source>Zoom &amp;out</source>
        <translation>&amp;Zmenšit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>Zoom rese&amp;t</source>
        <translation>Vrá&amp;tit původní velikost zobrazení</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="322"/>
        <source>&amp;Find...</source>
        <translation>&amp;Najít…</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="325"/>
        <source>Handle history...</source>
        <translation>Zpracovat historii...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>&amp;Save Session</source>
        <translation>&amp;Uložit relaci</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>&amp;Load Session</source>
        <translation>&amp;Načíst relaci</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="346"/>
        <source>&amp;Toggle Menu</source>
        <translation>Zobraz./skrý&amp;t nabídku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="351"/>
        <source>Rename session</source>
        <translation>Přejmenovat relaci</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>&amp;New Tab</source>
        <translation>&amp;Nový panel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>New Tab From &amp;Preset</source>
        <translation>Nový panel z &amp;přednastavených</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>1 &amp;Terminal</source>
        <translation>1 &amp;terminál</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>2 vodorovné &amp;terminály</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="369"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>2 s&amp;vislé terminály</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="371"/>
        <source>4 Terminal&amp;s</source>
        <translation>4 ter&amp;minály</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="377"/>
        <source>&amp;Close Tab</source>
        <translation>&amp;Zavřít panel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="380"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nové okno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="385"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;Nastavení…</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>&amp;Quit</source>
        <translation>&amp;Ukončit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="395"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Skrýt okraje oken</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>&amp;Show Tab Bar</source>
        <translation>&amp;Zobrazovat lištu panelů</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="421"/>
        <source>Fullscreen</source>
        <translation>Na celou obrazovku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="427"/>
        <source>Toggle Bookmarks</source>
        <translation>Zobraz./skrýt záložky</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <source>&amp;Bottom</source>
        <translation>&amp;Dole</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>&amp;Top</source>
        <translation>&amp;Nahoře</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <location filename="../mainwindow.cpp" line="473"/>
        <source>&amp;Right</source>
        <translation>Vp&amp;ravo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="438"/>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>&amp;Left</source>
        <translation>V&amp;levo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="456"/>
        <source>&amp;Tabs Layout</source>
        <translation>&amp;Rozvržení panelů</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>&amp;None</source>
        <translation>&amp;Nezobrazovat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="490"/>
        <source>S&amp;crollbar Layout</source>
        <translation>&amp;Zobrazení posuvníku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>&amp;BlockCursor</source>
        <translation>&amp;Blokový ukazatel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="504"/>
        <source>&amp;UnderlineCursor</source>
        <translation>Podtržítkový &amp;ukazatel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="505"/>
        <source>&amp;IBeamCursor</source>
        <translation>Ukazatel v podobě sv&amp;islice</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="522"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation>Tvar textového &amp;ukazatele</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="622"/>
        <source>Exit QTerminal</source>
        <translation>Ukončit QTerminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="624"/>
        <source>Do not ask again</source>
        <translation>Příště se neptat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="632"/>
        <source>Are you sure you want to exit?</source>
        <translation>Opravdu chcete program ukončit?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <source>A lightweight multiplatform terminal emulator</source>
        <translation>Nenáročný emulátor terminálu pro více systémů</translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="586"/>
        <source>Emulation</source>
        <translation>Emulace</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="47"/>
        <source>Shortcuts</source>
        <translation>Klávesové zkratky</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>Nastavení terminálu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="31"/>
        <source>Appearance</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="39"/>
        <location filename="../forms/propertiesdialog.ui" line="611"/>
        <source>Behavior</source>
        <translation>Chování</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="55"/>
        <source>Dropdown</source>
        <translation>Ve vysouvacím režimu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="63"/>
        <source>Bookmarks</source>
        <translation>Záložky</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="258"/>
        <source>Hide tab bar with only one tab</source>
        <translation>Při pouze jediném panelu skrýt lištu panelů</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="275"/>
        <source>Color scheme</source>
        <translation>Barevné schéma</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="371"/>
        <source>Scrollbar position</source>
        <translation>Pozice posuvníku</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="204"/>
        <source>Start with preset:</source>
        <translation>Spustit s přednastavením:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="404"/>
        <source>Show a border around the current terminal</source>
        <translation>Zobrazit okraj okolo právě používaného terminálu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="381"/>
        <source>Terminal transparency</source>
        <translation>Průhlednost terminálu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="394"/>
        <source>Application transparency</source>
        <translation>Průhlednost aplikace</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="215"/>
        <source>None (single terminal)</source>
        <translation>Žádné (jediný terminál)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="220"/>
        <source>2 terminals horizontally</source>
        <translation>2 terminály vodorovně</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="225"/>
        <source>2 terminals vertically</source>
        <translation>2 terminály svisle</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="230"/>
        <source>4 terminals</source>
        <translation>4 terminály</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="148"/>
        <source>Font</source>
        <translation>Písmo</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="184"/>
        <source>&amp;Change...</source>
        <translation>&amp;Změnit…</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="454"/>
        <source>Tabs position</source>
        <translation>Pozice panelů</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="238"/>
        <source>Widget style</source>
        <translation>Styl ovládacích prvků</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="194"/>
        <source>Show the menu bar</source>
        <translation>Zobrazovat lištu nabídek</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="464"/>
        <source>Change window title based on current terminal</source>
        <translation>Změnit nadpis okna podle právě zaměřeného terminálu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="481"/>
        <source>Change window icon based on current terminal</source>
        <translation>Změnit ikonu okna podle právě zaměřeného terminálu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="418"/>
        <source>Enable bi-directional text support</source>
        <translation>Zapnout podporu pro text obsahující směr zleva doprava i zprava doleva</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="265"/>
        <source>Background image:</source>
        <translation>Obrázek na pozadí:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="290"/>
        <source>Select</source>
        <translation>Vybrat</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="488"/>
        <source>Show terminal size on resize</source>
        <translation>Při změně velikosti terminálu zobrazit jeho rozměry</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="411"/>
        <location filename="../forms/propertiesdialog.ui" line="444"/>
        <source>px</source>
        <translation>_obraz. bodů</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="361"/>
        <source>Show close button on each tab</source>
        <translation>Zobrazit tlačítko zavírání na každém panelu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="248"/>
        <source>Terminal margin</source>
        <translation>Okraj terminálu (odsazení obsahu od jeho rámečku)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="498"/>
        <source>Use box drawing characters contained in the font</source>
        <translation>Použít znak, představující obdélník, z písma</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="505"/>
        <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
        <translation>Urychlovače jsou zobrazeny po stisknutí Alt a mohou kolidovat s terminálem.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="508"/>
        <source>No menu bar accelerator</source>
        <translation>Žádný urychlovač lišty nabídek</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="711"/>
        <source>Action after paste</source>
        <translation>Akce po vložení</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="748"/>
        <source>Confirm multiline paste</source>
        <translation>Vyžadovat potvrzení při vkládání víceřádkového textu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="789"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation>Odebrat nové řádky následující po konci vkládaného textu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="724"/>
        <source>Open new terminals in current working directory</source>
        <translation>Otevírat nové terminály ve stávající pracovní složce</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="755"/>
        <source>Save Size when closing</source>
        <translation>Při zavírání uložit velikost</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="796"/>
        <source>Save Position when closing</source>
        <translation>Při zavírání uložit pozici</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="772"/>
        <source>Ask for confirmation when closing</source>
        <translation>Při zavírání vyžadovat potvrzení</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="816"/>
        <source>Unlimited history</source>
        <translation>Neomezená historie</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="782"/>
        <source>History size (in lines)</source>
        <translation>Hloubka historie (v řádcích)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="741"/>
        <source>Default $TERM</source>
        <translation>Výchozí $TERM</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="632"/>
        <source>Start with this size:</source>
        <translation>Spustit s touto velikostí:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="299"/>
        <source>Background mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="307"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="312"/>
        <source>Stretch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="317"/>
        <source>Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="322"/>
        <source>Fit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="327"/>
        <source>Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="495"/>
        <source>Specify whether box drawing characters should be drawn by QTerminal internally or left to underlying font rendering libraries.</source>
        <translation>Určete, zda mají být znaky pro kreslení rámečku kresleny QTerminalem vnitřně nebo ponechány na podkladových knihovnách vykreslování písem.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="515"/>
        <source>Toggles usage of bold font face for rendering intense colors</source>
        <translation>Přepíná použití tučného písma pro vykreslení výrazných barev</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="518"/>
        <source>Use bold font face for intense colors</source>
        <translation>Pro výrazné barvy použít tučné písmo</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="525"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Skrýt okraje oken</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="595"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;If you are not sure, use the &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Které chování napodobit. Všimněte si, že toto nemusí odpovídat vašemu operačnímu systému.&lt;/p&gt;&lt;p&gt;Pokud si nejste jisti, použijte &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulaci.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="617"/>
        <source>This command will be run with an argument containing the file name of a tempfile containing the scrollback history</source>
        <translation>Tento příkaz bude spuštěn s argumentem obsahujícím název souboru dočasného souboru obsahujícího historii posouvání</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="620"/>
        <source>Handle history command</source>
        <translation>Zpracovat příkaz pro historii</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="639"/>
        <location filename="../forms/propertiesdialog.ui" line="653"/>
        <source> px</source>
        <translation> obr. bodů</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="660"/>
        <source>Get current size</source>
        <translation>Získat stávající velikost</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="731"/>
        <source>Open new tab to the right of the active tab</source>
        <translation>Otevřít novou kartu napravo od činné karty</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="734"/>
        <source>If unchecked the new tab will be opened as the rightmost tab</source>
        <translation>Pokud není zaškrtnuto, nová karta se otevře jako karta zcela vpravo</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="762"/>
        <source>Close tab on middle-click</source>
        <translation>Zavřít kartu klepnutím prostředního tlačítka myši</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="823"/>
        <source>Forcefully disable bracketed paste mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="826"/>
        <source>Bracketed paste mode is useful for pasting multiline strings.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="844"/>
        <source>To edit a Shortcut:
1. Double-click its Key
2. Press the desired combination and release it
3. Click on a Shortcut or press Enter

To remove/disable a Shortcut, at point 2 press only a modifier (like Shift)</source>
        <translation>Pro upravení zkratky:
1. Poklepejte na její klávesu
2. Stiskněte požadovanou kombinaci a uvolněte ji
3. Klepněte na zástupce nebo stiskněte klávesu Enter

pro odebrání/zakázání zkratky, v bodě 2 stiskněte pouze modifikátor (například Shift)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="909"/>
        <source>Height</source>
        <translation>Výška</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="919"/>
        <location filename="../forms/propertiesdialog.ui" line="936"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="926"/>
        <source>Width</source>
        <translation>Šířka</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="982"/>
        <source>Edit bookmark file contents</source>
        <translation>Upravit obsah souboru se záložkami</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1004"/>
        <source>Enable bookmarks</source>
        <translation>Používat záložky</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1013"/>
        <source>Bookmark file</source>
        <translation>Soubor se záložkami</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="891"/>
        <source>Show on start</source>
        <translation>Při spuštění zobrazit</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="335"/>
        <source>Cursor shape</source>
        <translation>Tvar kurzoru</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="471"/>
        <source>Fixed tab width:</source>
        <translation>Pevná velikost panelu:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="898"/>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="950"/>
        <source>Shortcut:</source>
        <translation>Klávesová zkratka:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1026"/>
        <source>Find...</source>
        <translation>Najít…</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1035"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>Můžete stanovit své vlastní umístění souboru se záložkami. To umožňuje snadné sdílení záložek pomocí nástrojů, jako jsou NextCloud nebo Dropbox.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="117"/>
        <location filename="../forms/propertiesdialog.ui" line="425"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="874"/>
        <source>Shortcut</source>
        <translation>Zkratka pro</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="879"/>
        <source>Key</source>
        <translation>Klávesy</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="155"/>
        <source>No scrollbar</source>
        <translation>Žádný posuvník</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="155"/>
        <location filename="../propertiesdialog.cpp" line="161"/>
        <source>Left</source>
        <translation>Vlevo</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="155"/>
        <location filename="../propertiesdialog.cpp" line="161"/>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="161"/>
        <source>Top</source>
        <translation>Nahoře</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="161"/>
        <source>Bottom</source>
        <translation>Dole</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="174"/>
        <source>BlockCursor</source>
        <translation>Blokový kurzor</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="174"/>
        <source>UnderlineCursor</source>
        <translation>Podtržítkový kurzor</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="174"/>
        <source>IBeamCursor</source>
        <translation>Ukazatel v podobě svislice</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="192"/>
        <source>No move</source>
        <translation>Nepřesouvat se</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="192"/>
        <source>Scrolling to top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="192"/>
        <source>Scrolling to bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="390"/>
        <source>Images (*.bmp *.jpg *.png *.svg *.xpm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="199"/>
        <location filename="../propertiesdialog.cpp" line="294"/>
        <source>System Default</source>
        <translation>Dle výchozího nastavení systému</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="389"/>
        <source>Choose a background image</source>
        <translation>Zvolte obrázek pro pozadí</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="466"/>
        <source>Open or create bookmarks file</source>
        <translation>Otevřít nebo vytvořit soubor se záložkami</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bookmarkswidget.cpp" line="108"/>
        <source>Local Bookmarks</source>
        <translation>Lokální záložky</translation>
    </message>
    <message>
        <location filename="../bookmarkswidget.cpp" line="166"/>
        <source>Synchronized Bookmarks</source>
        <translation>Synchronizované záložky</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../tabwidget.cpp" line="78"/>
        <location filename="../tabwidget.cpp" line="232"/>
        <source>Shell No. %1</source>
        <translation>Shell číslo %1</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="200"/>
        <source>Tab name</source>
        <translation>Název panelu</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="201"/>
        <source>New tab name:</source>
        <translation>Nový název panelu:</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="221"/>
        <source>Select new tab title color</source>
        <translation>Vyberte novou barvu pro titulek panelu</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="242"/>
        <source>Close session</source>
        <translation>Zavřít relaci</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="244"/>
        <source>Change title color</source>
        <translation>Změnit barvu titulku</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../termwidgetholder.cpp" line="79"/>
        <source>Load Session</source>
        <translation>Načíst relaci</translation>
    </message>
    <message>
        <location filename="../termwidgetholder.cpp" line="80"/>
        <source>List of saved sessions:</source>
        <translation>Seznam uložených relací:</translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Hlavní okno</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="59"/>
        <source>&amp;File</source>
        <translation>&amp;Soubor</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="67"/>
        <source>&amp;Actions</source>
        <translation>&amp;Akce</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>&amp;Nápověda</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="79"/>
        <source>&amp;View</source>
        <translation>&amp;Zobrazení</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="84"/>
        <source>&amp;Edit</source>
        <translation>Úp&amp;ravy</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="100"/>
        <source>&amp;About...</source>
        <translation>O &amp;aplikaci…</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="105"/>
        <source>About &amp;Qt...</source>
        <translation>O &amp;Qt…</translation>
    </message>
</context>
</TS>
